/* -*- mode: c++; indent-tabs-mode: nil -*- */
/** @file SSH2Base.qpp defines the SSH2Base class */
/*
    QC_SSH2Base.qpp

    libssh2 ssh2 client integration in Qore

    Qore Programming Language

    Copyright 2009 Wolfgang Ritzinger
    Copyright 2010 - 2019 Qore Technologies, s.r.o.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "QC_SSH2Base.h"
#include "SSH2Client.h"

#ifndef _QORE_HAS_SOCKET_PERF_API
static AbstractQoreNode *missing_method_error(const char *meth, const char *qv, ExceptionSink *xsink) {
   xsink->raiseException("MISSING-FEATURE-ERROR", "the %s() method is not available on this build; to use thie method compile the ssh2 module with Qore v%s of higher and reinstall", meth, qv);
   return 0;
}
#endif
/* Qore class Qore::SSH2::SSH2Base */

qore_classid_t CID_SSH2BASE;
QoreClass* QC_SSH2BASE;

// nothing SSH2Base::clearStats(){}
static QoreValue SSH2Base_clearStats(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 246 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    #ifdef _QORE_HAS_SOCKET_PERF_API
   myself->clearStats();
#else
   missing_method_error("SSH2Base::clearStats", "0.8.10", xsink);
   return 0;
#endif
    return QoreValue();
}

// nothing SSH2Base::clearWarningQueue(){}
static QoreValue SSH2Base_clearWarningQueue(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 149 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    #ifdef _QORE_HAS_SOCKET_PERF_API
   myself->clearWarningQueue(xsink);
#else
   missing_method_error("SSH2Base::clearWarningQueue", "0.8.10", xsink);
   return 0;
#endif
    return QoreValue();
}

// nothing SSH2Base::connect(timeout timeout = 1m){}
static QoreValue SSH2Base_connect_Vt(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_VALUE_INT(args, 0);
# 67 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    myself->connect(timeout, xsink);
    return QoreValue();
}

// bool SSH2Base::connected(){}
static QoreValue SSH2Base_connected(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 135 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    return myself->sshConnected();
}

// SSH2Base::constructor() {}
static void SSH2Base_constructor(QoreObject* self, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 49 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
xsink->raiseException("SSH2BASE-CONSTRUCTOR-ERROR", "this class is an abstract class and cannot be instantiated directly or directly inherited by a user-defined class");
}

// nothing SSH2Base::disconnect(timeout timeout = 1m){}
static QoreValue SSH2Base_disconnect_Vt(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_VALUE_INT(args, 0);
# 78 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    myself->disconnect(0, timeout, xsink);
    return QoreValue();
}

// *string SSH2Base::getAuthenticatedWith(){}
static QoreValue SSH2Base_getAuthenticatedWith(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 327 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    SimpleRefHolder<QoreStringNode> rv(new QoreStringNode);
    myself->getAuthenticatedWithLocked(**rv);
    return rv->empty() ? nullptr : rv.release();
}

// *string SSH2Base::getHost(){}
static QoreValue SSH2Base_getHost(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 260 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    SimpleRefHolder<QoreStringNode> rv(new QoreStringNode);
    myself->getHostLocked(**rv);
    return rv->empty() ? nullptr : rv.release();
}

// *string SSH2Base::getKeyPriv(){}
static QoreValue SSH2Base_getKeyPriv(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 302 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    SimpleRefHolder<QoreStringNode> rv(new QoreStringNode);
    myself->getKeyPrivLocked(**rv);
    return rv->empty() ? nullptr : rv.release();
}

// *string SSH2Base::getKeyPub(){}
static QoreValue SSH2Base_getKeyPub(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 313 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    SimpleRefHolder<QoreStringNode> rv(new QoreStringNode);
    myself->getKeyPubLocked(**rv);
    return rv->empty() ? nullptr : rv.release();
}

// *string SSH2Base::getPassword(){}
static QoreValue SSH2Base_getPassword(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 291 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    SimpleRefHolder<QoreStringNode> rv(new QoreStringNode);
    myself->getPasswordLocked(**rv);
    return rv->empty() ? nullptr : rv.release();
}

// int SSH2Base::getPort(){}
static QoreValue SSH2Base_getPort(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 271 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    return myself->getPortLocked();
}

// hash<auto> SSH2Base::getUsageInfo(){}
static QoreValue SSH2Base_getUsageInfo(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 227 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    #ifdef _QORE_HAS_SOCKET_PERF_API
   return myself->getUsageInfo();
#else
   missing_method_error("SSH2Base::getUsageInfo", "0.8.10", xsink);
   return 0;
#endif
    return QoreValue();
}

// *string SSH2Base::getUser(){}
static QoreValue SSH2Base_getUser(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 280 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    SimpleRefHolder<QoreStringNode> rv(new QoreStringNode);
    myself->getUserLocked(**rv);
    return rv->empty() ? nullptr : rv.release();
}

// nothing SSH2Base::setKeys(string priv_key, *string pub_key){}
static QoreValue SSH2Base_setKeys_VsNs(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    const QoreStringNode* priv_key = HARD_QORE_VALUE_STRING(args, 0);
    const QoreStringNode* pub_key = get_param_value(args, 1).get<const QoreStringNode>();
# 123 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    myself->setKeys(priv_key->getBuffer(), pub_key ? pub_key->getBuffer() : 0, xsink);
    return QoreValue();
}

// nothing SSH2Base::setPassword(string pass){}
static QoreValue SSH2Base_setPassword_Vs(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    const QoreStringNode* pass = HARD_QORE_VALUE_STRING(args, 0);
# 104 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    if (myself->setPassword(pass->getBuffer()))
      xsink->raiseException(SSH2_CONNECTED, "usage of SSH2Base::setPassword() is not allowed when connected");
    return QoreValue();
}

// nothing SSH2Base::setUser(string user){}
static QoreValue SSH2Base_setUser_Vs(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    const QoreStringNode* user = HARD_QORE_VALUE_STRING(args, 0);
# 91 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    if (myself->setUser(user->getBuffer()))
      xsink->raiseException(SSH2_CONNECTED, "usage of SSH2Base::setUser() is not allowed when connected");
    return QoreValue();
}

// nothing SSH2Base::setWarningQueue(int warning_ms, int warning_bs, Queue queue, any arg, timeout min_ms = 1s){}
static QoreValue SSH2Base_setWarningQueue_ViViC5QueueVaVt(QoreObject* self, SSH2Client* myself, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 warning_ms = HARD_QORE_VALUE_INT(args, 0);
    int64 warning_bs = HARD_QORE_VALUE_INT(args, 1);
    HARD_QORE_VALUE_OBJ_DATA(queue, Queue, args, 2, CID_QUEUE, "SSH2Base::setWarningQueue()", "Queue", xsink);
    if (*xsink)
        return 0;
    QoreValue arg = get_param_value(args, 3);
    int64 min_ms = HARD_QORE_VALUE_INT(args, 4);
# 189 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Base.qpp"
    #ifdef _QORE_HAS_QUEUE_OBJECT
   ReferenceHolder<Queue> q(queue, xsink);
#else
   ReferenceHolder<AbstractPrivateData> q((AbstractPrivateData*)queue, xsink);
#endif
#ifdef _QORE_HAS_SOCKET_PERF_API
   if (queue->getMax() != -1) {
      xsink->raiseException("QUEUE-ERROR", "the Queue object passed as a maximum size of %d entr%s, which could cause internal I/O to freeze in the Socket object if used; use a Queue object with no maximum size for I/O monitoring", queue->getMax(), queue->getMax() == 1 ? "y" : "ies");
      return 0;
   }
   // pass reference from QoreObject::getReferencedPrivateData() to function
   myself->setWarningQueue(xsink, warning_ms, warning_bs, q.release(), arg.refSelf(), min_ms);
#else
   missing_method_error("SSH2Base::setWarningQueue", "0.8.10", xsink);
   return 0;
#endif
    return QoreValue();
}

DLLLOCAL void preinitSSH2BaseClass() {
    QC_SSH2BASE = new QoreClass("SSH2Base", "::Qore::SSH2::SSH2Base", QDOM_NETWORK);
    CID_SSH2BASE = QC_SSH2BASE->getID();
    QC_SSH2BASE->setSystem();
}

DLLLOCAL QoreClass* initSSH2BaseClass(QoreNamespace& ns) {
    if (!QC_SSH2BASE)
        preinitSSH2BaseClass();

    // nothing SSH2Base::clearStats(){}
    QC_SSH2BASE->addMethod("clearStats", (q_method_n_t)SSH2Base_clearStats, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo);

    // nothing SSH2Base::clearWarningQueue(){}
    QC_SSH2BASE->addMethod("clearWarningQueue", (q_method_n_t)SSH2Base_clearWarningQueue, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo);

    // nothing SSH2Base::connect(timeout timeout = 1m){}
    QC_SSH2BASE->addMethod("connect", (q_method_n_t)SSH2Base_connect_Vt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, QoreSimpleValue().assign(DateTimeNode::makeRelative(0, 0, 0, 0, 1, 0, 0)), "timeout");

    // bool SSH2Base::connected(){}
    QC_SSH2BASE->addMethod("connected", (q_method_n_t)SSH2Base_connected, Public, QCF_CONSTANT, QDOM_DEFAULT, boolTypeInfo);

    // SSH2Base::constructor() {}
    QC_SSH2BASE->addConstructor(SSH2Base_constructor, Public, QCF_NO_FLAGS, QDOM_DEFAULT);

    // nothing SSH2Base::disconnect(timeout timeout = 1m){}
    QC_SSH2BASE->addMethod("disconnect", (q_method_n_t)SSH2Base_disconnect_Vt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, QoreSimpleValue().assign(DateTimeNode::makeRelative(0, 0, 0, 0, 1, 0, 0)), "timeout");

    // *string SSH2Base::getAuthenticatedWith(){}
    QC_SSH2BASE->addMethod("getAuthenticatedWith", (q_method_n_t)SSH2Base_getAuthenticatedWith, Public, QCF_NO_FLAGS, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *string SSH2Base::getHost(){}
    QC_SSH2BASE->addMethod("getHost", (q_method_n_t)SSH2Base_getHost, Public, QCF_NO_FLAGS, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *string SSH2Base::getKeyPriv(){}
    QC_SSH2BASE->addMethod("getKeyPriv", (q_method_n_t)SSH2Base_getKeyPriv, Public, QCF_NO_FLAGS, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *string SSH2Base::getKeyPub(){}
    QC_SSH2BASE->addMethod("getKeyPub", (q_method_n_t)SSH2Base_getKeyPub, Public, QCF_NO_FLAGS, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // *string SSH2Base::getPassword(){}
    QC_SSH2BASE->addMethod("getPassword", (q_method_n_t)SSH2Base_getPassword, Public, QCF_NO_FLAGS, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // int SSH2Base::getPort(){}
    QC_SSH2BASE->addMethod("getPort", (q_method_n_t)SSH2Base_getPort, Public, QCF_NO_FLAGS, QDOM_DEFAULT, bigIntTypeInfo);

    // hash<auto> SSH2Base::getUsageInfo(){}
    QC_SSH2BASE->addMethod("getUsageInfo", (q_method_n_t)SSH2Base_getUsageInfo, Public, QCF_CONSTANT, QDOM_DEFAULT, autoHashTypeInfo);

    // *string SSH2Base::getUser(){}
    QC_SSH2BASE->addMethod("getUser", (q_method_n_t)SSH2Base_getUser, Public, QCF_NO_FLAGS, QDOM_DEFAULT, stringOrNothingTypeInfo);

    // nothing SSH2Base::setKeys(string priv_key, *string pub_key){}
    QC_SSH2BASE->addMethod("setKeys", (q_method_n_t)SSH2Base_setKeys_VsNs, Public, QCF_NO_FLAGS, QDOM_FILESYSTEM, nothingTypeInfo, 2, stringTypeInfo, QORE_PARAM_NO_ARG, "priv_key", stringOrNothingTypeInfo, QORE_PARAM_NO_ARG, "pub_key");

    // nothing SSH2Base::setPassword(string pass){}
    QC_SSH2BASE->addMethod("setPassword", (q_method_n_t)SSH2Base_setPassword_Vs, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, stringTypeInfo, QORE_PARAM_NO_ARG, "pass");

    // nothing SSH2Base::setUser(string user){}
    QC_SSH2BASE->addMethod("setUser", (q_method_n_t)SSH2Base_setUser_Vs, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, stringTypeInfo, QORE_PARAM_NO_ARG, "user");

    // nothing SSH2Base::setWarningQueue(int warning_ms, int warning_bs, Queue queue, any arg, timeout min_ms = 1s){}
    QC_SSH2BASE->addMethod("setWarningQueue", (q_method_n_t)SSH2Base_setWarningQueue_ViViC5QueueVaVt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 5, bigIntTypeInfo, QORE_PARAM_NO_ARG, "warning_ms", bigIntTypeInfo, QORE_PARAM_NO_ARG, "warning_bs", QC_QUEUE->getTypeInfo(), QORE_PARAM_NO_ARG, "queue", anyTypeInfo, QORE_PARAM_NO_ARG, "arg", timeoutTypeInfo, QoreSimpleValue().assign(DateTimeNode::makeRelative(0, 0, 0, 0, 0, 1, 0)), "min_ms");

    return QC_SSH2BASE;
}
