/* -*- mode: c++; indent-tabs-mode: nil -*- */
/** @file SSH2Channel.qpp defines the SSH2Channel class */
/*
    QC_SSH2Channel.qpp

    libssh2 ssh2 channel integration into qore

    Copyright 2010 Wolfgang Ritzinger
    Copyright 2010 - 2020 Qore Technologies, s.r.o.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "SSH2Channel.h"
/* Qore class Qore::SSH2::SSH2Channel */

qore_classid_t CID_SSH2CHANNEL;
QoreClass* QC_SSH2CHANNEL;

// nothing SSH2Channel::close(timeout timeout = -1){}
static QoreValue SSH2Channel_close_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_VALUE_INT(args, 0);
# 365 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    c->close(xsink, timeout);
    return QoreValue();
}

// SSH2Channel::constructor() {}
static void SSH2Channel_constructor(QoreObject* self, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 38 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
xsink->raiseException("SSH2CHANNEL-CONSTRUCTOR-ERROR", "this class cannot be directly constructed but is created from methods in the SSH2Client class (ex: SSH2Client::openSessionChannel())");
}

// SSH2Channel::copy() {}
static void SSH2Channel_copy(QoreObject* self, QoreObject* old, SSH2Channel* c, ExceptionSink* xsink) {
# 45 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
xsink->raiseException("SSH2CHANNEL-COPY-ERROR", "copying SSH2Channel objects is not supported");
}

// SSH2Channel::destructor() {}
static void SSH2Channel_destructor(QoreObject* self, SSH2Channel* c, ExceptionSink* xsink) {
# 52 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
c->destructor();
    c->deref();
}

// bool SSH2Channel::eof(){}
static QoreValue SSH2Channel_eof(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 139 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    bool b = c->eof(xsink);
    return *xsink ? QoreValue(b) : QoreValue();
}

// nothing SSH2Channel::exec(string command, timeout timeout = -1){}
static QoreValue SSH2Channel_exec_VsVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    const QoreStringNode* command = HARD_QORE_VALUE_STRING(args, 0);
    int64 timeout = HARD_QORE_VALUE_INT(args, 1);
# 188 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    c->exec(command->getBuffer(), timeout, xsink);
    return QoreValue();
}

// nothing SSH2Channel::extendedDataIgnore(timeout timeout = -1){}
static QoreValue SSH2Channel_extendedDataIgnore_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_VALUE_INT(args, 0);
# 478 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    c->extendedDataIgnore(xsink, timeout);
    return QoreValue();
}

// nothing SSH2Channel::extendedDataMerge(timeout timeout = -1){}
static QoreValue SSH2Channel_extendedDataMerge_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_VALUE_INT(args, 0);
# 463 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    c->extendedDataMerge(xsink, timeout);
    return QoreValue();
}

// nothing SSH2Channel::extendedDataNormal(timeout timeout = -1){}
static QoreValue SSH2Channel_extendedDataNormal_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_VALUE_INT(args, 0);
# 448 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    c->extendedDataNormal(xsink, timeout);
    return QoreValue();
}

// string SSH2Channel::getEncoding(){}
static QoreValue SSH2Channel_getEncoding(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 433 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    return new QoreStringNode(c->getEncoding()->getCode());
}

// int SSH2Channel::getExitStatus(){}
static QoreValue SSH2Channel_getExitStatus(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
# 394 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    return c->getExitStatus(xsink);
}

// string SSH2Channel::read(softint stream_id = 0, timeout timeout = 10000){}
static QoreValue SSH2Channel_read_viVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 stream_id = HARD_QORE_VALUE_INT(args, 0);
    int64 timeout = HARD_QORE_VALUE_INT(args, 1);
# 221 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    if (stream_id < 0) {
      xsink->raiseException("SSH2CHANNEL-READ-ERROR", "expecting non-negative integer for stream id as optional first argument to SSH2Channel::read([streamid], [timeout_ms]), got " QLLD " instead; use 0 for stdin, 1 for stderr", stream_id);
      return 0;
   }
   return c->read(xsink, stream_id, timeout);
}

// binary SSH2Channel::readBinary(softint stream_id = 0, timeout timeout = 10000){}
static QoreValue SSH2Channel_readBinary_viVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 stream_id = HARD_QORE_VALUE_INT(args, 0);
    int64 timeout = HARD_QORE_VALUE_INT(args, 1);
# 241 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    if (stream_id < 0) {
      xsink->raiseException("SSH2CHANNEL-READBINARY-ERROR", "expecting non-negative integer for stream id as optional first argument to SSH2Channel::readBinary([streamid], [timeout_ms]), got " QLLD " instead; use 0 for stdin, 1 for stderr", stream_id);
      return 0;
   }
   return c->readBinary(xsink, stream_id, timeout);
}

// binary SSH2Channel::readBinaryBlock(softint size, softint stream_id = 0, timeout timeout = -1){}
static QoreValue SSH2Channel_readBinaryBlock_viviVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 size = HARD_QORE_VALUE_INT(args, 0);
    int64 stream_id = HARD_QORE_VALUE_INT(args, 1);
    int64 timeout = HARD_QORE_VALUE_INT(args, 2);
# 293 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    static const char *SSH2CHANNEL_READBINARYBLOCK_ERROR = "SSH2CHANNEL-READBINARYBLOCK-ERROR";
   if (size <= 0) {
      xsink->raiseException(SSH2CHANNEL_READBINARYBLOCK_ERROR, "expecting a positive size for the block size to read, got " QLLD " instead; use SSH2Channel::readBinary() to read available data without a block size", size);
      return 0;
   }
   if (stream_id < 0) {
      xsink->raiseException(SSH2CHANNEL_READBINARYBLOCK_ERROR, "expecting non-negative integer for stream id as optional second argument to SSH2Channel::readBinaryBlock(blocksize, [streamid], [timeout_ms]), got " QLLD " instead; use 0 for stdin, 1 for stderr", stream_id);
      return 0;
   }
   return c->readBinary(size, stream_id, timeout, xsink);
}

// string SSH2Channel::readBlock(softint size, softint stream_id = 0, timeout timeout = -1){}
static QoreValue SSH2Channel_readBlock_viviVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 size = HARD_QORE_VALUE_INT(args, 0);
    int64 stream_id = HARD_QORE_VALUE_INT(args, 1);
    int64 timeout = HARD_QORE_VALUE_INT(args, 2);
# 264 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    static const char *SSH2CHANNEL_READBLOCK_ERROR = "SSH2CHANNEL-READBLOCK-ERROR";
   if (size <= 0) {
      xsink->raiseException(SSH2CHANNEL_READBLOCK_ERROR, "expecting a positive size for the block size to read, got " QLLD " instead; use SSH2Channel::read() to read available data without a block size", size);
      return 0;
   }
   if (stream_id < 0) {
      xsink->raiseException(SSH2CHANNEL_READBLOCK_ERROR, "expecting non-negative integer for stream id as optional second argument to SSH2Channel::readBlock(blocksize, [streamid], [timeout_ms]), got " QLLD " instead; use 0 for stdin, 1 for stderr", stream_id);
      return 0;
   }

   return c->read(size, stream_id, timeout, xsink);
}

// nothing SSH2Channel::requestPty(string term = "vanilla", string modes = "", softint width = LIBSSH2_TERM_WIDTH, softint height = LIBSSH2_TERM_HEIGHT, softint width_px = LIBSSH2_TERM_WIDTH_PX, softint height_px = LIBSSH2_TERM_HEIGHT_PX, timeout timeout = -1){}
static QoreValue SSH2Channel_requestPty_VsVsviviviviVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    const QoreStringNode* term = HARD_QORE_VALUE_STRING(args, 0);
    const QoreStringNode* modes = HARD_QORE_VALUE_STRING(args, 1);
    int64 width = HARD_QORE_VALUE_INT(args, 2);
    int64 height = HARD_QORE_VALUE_INT(args, 3);
    int64 width_px = HARD_QORE_VALUE_INT(args, 4);
    int64 height_px = HARD_QORE_VALUE_INT(args, 5);
    int64 timeout = HARD_QORE_VALUE_INT(args, 6);
# 92 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    static const char *SSH2CHANNEL_REQUESTPTY_ERR = "SSH2CHANNEL-REQUESTPTY-ERROR";

   if (width < 0) {
      xsink->raiseException(SSH2CHANNEL_REQUESTPTY_ERR, "terminal width given as the optional third argument to SSH2Channel::requestPty() must be non-negative; value given: %d", width);
      return 0;
   }
   if (height < 0) {
      xsink->raiseException(SSH2CHANNEL_REQUESTPTY_ERR, "terminal height given as the optional fourth argument to SSH2Channel::requestPty() must be non-negative; value given: %d", height);
      return 0;
   }
   if (width_px < 0) {
      xsink->raiseException(SSH2CHANNEL_REQUESTPTY_ERR, "terminal pixel width given as the optional fifth argument to SSH2Channel::requestPty() must be non-negative; value given: %d", width_px);
      return 0;
   }
   if (height_px < 0) {
      xsink->raiseException(SSH2CHANNEL_REQUESTPTY_ERR, "terminal pixel height given as the optional sixth argument to SSH2Channel::requestPty() must be non-negative; value given: %d", height_px);
      return 0;
   }

   c->requestPty(xsink, *term, *modes, (int)width, (int)height, (int)width_px, (int)height_px, timeout);
   return 0;
}

// nothing SSH2Channel::requestX11Forwarding(softint screen_no = 0, bool single_connection = False, string auth_proto = "", string auth_cookie = "", timeout timeout = -1){}
static QoreValue SSH2Channel_requestX11Forwarding_viVbVsVsVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 screen_no = HARD_QORE_VALUE_INT(args, 0);
    bool single_connection = HARD_QORE_VALUE_BOOL(args, 1);
    const QoreStringNode* auth_proto = HARD_QORE_VALUE_STRING(args, 2);
    const QoreStringNode* auth_cookie = HARD_QORE_VALUE_STRING(args, 3);
    int64 timeout = HARD_QORE_VALUE_INT(args, 4);
# 413 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    c->requestX11Forwarding(xsink, (int)screen_no, single_connection, auth_proto->strlen() ? auth_proto->getBuffer() : 0, auth_cookie->strlen() ? auth_cookie->getBuffer() : 0, timeout);
    return QoreValue();
}

// nothing SSH2Channel::sendEof(timeout timeout = -1){}
static QoreValue SSH2Channel_sendEof_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_VALUE_INT(args, 0);
# 155 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    c->sendEof(xsink, timeout);
    return QoreValue();
}

// nothing SSH2Channel::setEncoding(string encoding){}
static QoreValue SSH2Channel_setEncoding_Vs(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    const QoreStringNode* encoding = HARD_QORE_VALUE_STRING(args, 0);
# 423 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    c->setEncoding(QEM.findCreate(encoding));
    return QoreValue();
}

// nothing SSH2Channel::setenv(string var, string value, timeout timeout = -1){}
static QoreValue SSH2Channel_setenv_VsVsVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    const QoreStringNode* var = HARD_QORE_VALUE_STRING(args, 0);
    const QoreStringNode* value = HARD_QORE_VALUE_STRING(args, 1);
    int64 timeout = HARD_QORE_VALUE_INT(args, 2);
# 70 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    c->setenv(var->getBuffer(), value->getBuffer(), timeout, xsink);
   return 0;
}

// nothing SSH2Channel::shell(timeout timeout = -1){}
static QoreValue SSH2Channel_shell_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_VALUE_INT(args, 0);
# 127 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    c->shell(xsink, timeout);
    return QoreValue();
}

// nothing SSH2Channel::subsystem(string command, timeout timeout = -1){}
static QoreValue SSH2Channel_subsystem_VsVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    const QoreStringNode* command = HARD_QORE_VALUE_STRING(args, 0);
    int64 timeout = HARD_QORE_VALUE_INT(args, 1);
# 205 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    c->subsystem(command->getBuffer(), timeout, xsink);
    return QoreValue();
}

// nothing SSH2Channel::waitClosed(timeout timeout = -1){}
static QoreValue SSH2Channel_waitClosed_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_VALUE_INT(args, 0);
# 380 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    c->waitClosed(xsink, timeout);
    return QoreValue();
}

// nothing SSH2Channel::waitEof(timeout timeout = -1){}
static QoreValue SSH2Channel_waitEof_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_VALUE_INT(args, 0);
# 170 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    c->waitEof(xsink, timeout);
    return QoreValue();
}

// nothing SSH2Channel::write(data data, softint stream_id = 0, timeout timeout_ms = -1){}
static QoreValue SSH2Channel_write_VDviVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, q_rt_flags_t rtflags, ExceptionSink* xsink) {
    QoreValue data = get_param_value(args, 0);
    int64 stream_id = HARD_QORE_VALUE_INT(args, 1);
    int64 timeout_ms = HARD_QORE_VALUE_INT(args, 2);
# 319 "/home/abuild/rpmbuild/BUILD/qore-ssh2-module-1.4.2/src/QC_SSH2Channel.qpp"
    static const char *SSH2CHANNEL_WRITE_ERROR = "SSH2CHANNEL-WRITE-ERROR";
   const void *buf = 0;
   qore_size_t buflen;

   qore_type_t t = data.getType();

   TempEncodingHelper tmp;
   if (t == NT_STRING) {
      const QoreStringNode *str = data.get<const QoreStringNode>();
      tmp.set(str, c->getEncoding(), xsink);
      if (*xsink)
	 return 0;

      buf = tmp->getBuffer();
      buflen = tmp->strlen();
   }
   else {
      const BinaryNode *b = data.get<const BinaryNode>();
      buf = b->getPtr();
      buflen = b->size();
   }

   // ignore zero-length writes
   if (!buflen)
      return 0;

   if (stream_id < 0) {
      xsink->raiseException(SSH2CHANNEL_WRITE_ERROR, "expecting non-negative integer for stream id as optional second argument to SSH2Channel::write(data data, softint streamid, timeout timeout_ms), got " QLLD " instead; use 0 for stdin, 1 for stderr", stream_id);
      return 0;
   }

   c->write(xsink, buf, buflen, stream_id, timeout_ms);
    return QoreValue();
}

DLLLOCAL void preinitSSH2ChannelClass() {
    QC_SSH2CHANNEL = new QoreClass("SSH2Channel", "::Qore::SSH2::SSH2Channel", QDOM_NETWORK);
    CID_SSH2CHANNEL = QC_SSH2CHANNEL->getID();
    QC_SSH2CHANNEL->setSystem();
}

DLLLOCAL QoreClass* initSSH2ChannelClass(QoreNamespace& ns) {
    if (!QC_SSH2CHANNEL)
        preinitSSH2ChannelClass();

    // nothing SSH2Channel::close(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("close", (q_method_n_t)SSH2Channel_close_Vt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // SSH2Channel::constructor() {}
    QC_SSH2CHANNEL->addConstructor(SSH2Channel_constructor, Public, QCF_NO_FLAGS, QDOM_DEFAULT);

    // SSH2Channel::copy() {}
    QC_SSH2CHANNEL->setCopy((q_copy_t)SSH2Channel_copy);

    // SSH2Channel::destructor() {}
    QC_SSH2CHANNEL->setDestructor((q_destructor_t)SSH2Channel_destructor);

    // bool SSH2Channel::eof(){}
    QC_SSH2CHANNEL->addMethod("eof", (q_method_n_t)SSH2Channel_eof, Public, QCF_NO_FLAGS, QDOM_DEFAULT, boolTypeInfo);

    // nothing SSH2Channel::exec(string command, timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("exec", (q_method_n_t)SSH2Channel_exec_VsVt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 2, stringTypeInfo, QORE_PARAM_NO_ARG, "command", timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // nothing SSH2Channel::extendedDataIgnore(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("extendedDataIgnore", (q_method_n_t)SSH2Channel_extendedDataIgnore_Vt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // nothing SSH2Channel::extendedDataMerge(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("extendedDataMerge", (q_method_n_t)SSH2Channel_extendedDataMerge_Vt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // nothing SSH2Channel::extendedDataNormal(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("extendedDataNormal", (q_method_n_t)SSH2Channel_extendedDataNormal_Vt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // string SSH2Channel::getEncoding(){}
    QC_SSH2CHANNEL->addMethod("getEncoding", (q_method_n_t)SSH2Channel_getEncoding, Public, QCF_CONSTANT, QDOM_DEFAULT, stringTypeInfo);

    // int SSH2Channel::getExitStatus(){}
    QC_SSH2CHANNEL->addMethod("getExitStatus", (q_method_n_t)SSH2Channel_getExitStatus, Public, QCF_NO_FLAGS, QDOM_DEFAULT, bigIntTypeInfo);

    // string SSH2Channel::read(softint stream_id = 0, timeout timeout = 10000){}
    QC_SSH2CHANNEL->addMethod("read", (q_method_n_t)SSH2Channel_read_viVt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, stringTypeInfo, 2, softBigIntTypeInfo, QoreSimpleValue().assign((int64)0), "stream_id", timeoutTypeInfo, QoreSimpleValue().assign((int64)10000), "timeout");

    // binary SSH2Channel::readBinary(softint stream_id = 0, timeout timeout = 10000){}
    QC_SSH2CHANNEL->addMethod("readBinary", (q_method_n_t)SSH2Channel_readBinary_viVt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, binaryTypeInfo, 2, softBigIntTypeInfo, QoreSimpleValue().assign((int64)0), "stream_id", timeoutTypeInfo, QoreSimpleValue().assign((int64)10000), "timeout");

    // binary SSH2Channel::readBinaryBlock(softint size, softint stream_id = 0, timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("readBinaryBlock", (q_method_n_t)SSH2Channel_readBinaryBlock_viviVt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, binaryTypeInfo, 3, softBigIntTypeInfo, QORE_PARAM_NO_ARG, "size", softBigIntTypeInfo, QoreSimpleValue().assign((int64)0), "stream_id", timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // string SSH2Channel::readBlock(softint size, softint stream_id = 0, timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("readBlock", (q_method_n_t)SSH2Channel_readBlock_viviVt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, stringTypeInfo, 3, softBigIntTypeInfo, QORE_PARAM_NO_ARG, "size", softBigIntTypeInfo, QoreSimpleValue().assign((int64)0), "stream_id", timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // nothing SSH2Channel::requestPty(string term = "vanilla", string modes = "", softint width = LIBSSH2_TERM_WIDTH, softint height = LIBSSH2_TERM_HEIGHT, softint width_px = LIBSSH2_TERM_WIDTH_PX, softint height_px = LIBSSH2_TERM_HEIGHT_PX, timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("requestPty", (q_method_n_t)SSH2Channel_requestPty_VsVsviviviviVt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 7, stringTypeInfo, QoreSimpleValue().assign(new QoreStringNode("vanilla")), "term", stringTypeInfo, QoreSimpleValue().assign(new QoreStringNode("")), "modes", softBigIntTypeInfo, QoreSimpleValue().assign((int64)LIBSSH2_TERM_WIDTH), "width", softBigIntTypeInfo, QoreSimpleValue().assign((int64)LIBSSH2_TERM_HEIGHT), "height", softBigIntTypeInfo, QoreSimpleValue().assign((int64)LIBSSH2_TERM_WIDTH_PX), "width_px", softBigIntTypeInfo, QoreSimpleValue().assign((int64)LIBSSH2_TERM_HEIGHT_PX), "height_px", timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // nothing SSH2Channel::requestX11Forwarding(softint screen_no = 0, bool single_connection = False, string auth_proto = "", string auth_cookie = "", timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("requestX11Forwarding", (q_method_n_t)SSH2Channel_requestX11Forwarding_viVbVsVsVt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 5, softBigIntTypeInfo, QoreSimpleValue().assign((int64)0), "screen_no", boolTypeInfo, QoreSimpleValue().assign(false), "single_connection", stringTypeInfo, QoreSimpleValue().assign(new QoreStringNode("")), "auth_proto", stringTypeInfo, QoreSimpleValue().assign(new QoreStringNode("")), "auth_cookie", timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // nothing SSH2Channel::sendEof(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("sendEof", (q_method_n_t)SSH2Channel_sendEof_Vt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // nothing SSH2Channel::setEncoding(string encoding){}
    QC_SSH2CHANNEL->addMethod("setEncoding", (q_method_n_t)SSH2Channel_setEncoding_Vs, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, stringTypeInfo, QORE_PARAM_NO_ARG, "encoding");

    // nothing SSH2Channel::setenv(string var, string value, timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("setenv", (q_method_n_t)SSH2Channel_setenv_VsVsVt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 3, stringTypeInfo, QORE_PARAM_NO_ARG, "var", stringTypeInfo, QORE_PARAM_NO_ARG, "value", timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // nothing SSH2Channel::shell(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("shell", (q_method_n_t)SSH2Channel_shell_Vt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // nothing SSH2Channel::subsystem(string command, timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("subsystem", (q_method_n_t)SSH2Channel_subsystem_VsVt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 2, stringTypeInfo, QORE_PARAM_NO_ARG, "command", timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // nothing SSH2Channel::waitClosed(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("waitClosed", (q_method_n_t)SSH2Channel_waitClosed_Vt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // nothing SSH2Channel::waitEof(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethod("waitEof", (q_method_n_t)SSH2Channel_waitEof_Vt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout");

    // nothing SSH2Channel::write(data data, softint stream_id = 0, timeout timeout_ms = -1){}
    QC_SSH2CHANNEL->addMethod("write", (q_method_n_t)SSH2Channel_write_VDviVt, Public, QCF_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 3, dataTypeInfo, QORE_PARAM_NO_ARG, "data", softBigIntTypeInfo, QoreSimpleValue().assign((int64)0), "stream_id", timeoutTypeInfo, QoreSimpleValue().assign((int64)-1), "timeout_ms");

    return QC_SSH2CHANNEL;
}
